@@ -8,7 +8,9 @@ use Apache::Constants qw(:response);
 use File::Spec::Functions qw(catfile);
 use Pipeline;
 use OpenFrame::Example::Redirector;
+use OpenFrame::Response;
 use OpenFrame::Segment::Apache;
+use OpenFrame::Segment::Apache::NoImages;
 use OpenFrame::Segment::ContentLoader;
 
 our $VERSION = '1.01';
@@ -21,6 +23,8 @@ sub handler {
   my $request = OpenFrame::Segment::Apache::Request->new();
   my $response = OpenFrame::Segment::Apache::Response->new();
   my $redirect = OpenFrame::Example::Redirector->new();
+  my $noimages = OpenFrame::Segment::Apache::NoImages->new()
+    ->directory($dir);
   my $content = OpenFrame::Segment::ContentLoader->new()
     ->directory($dir);
 
@@ -28,19 +32,24 @@ sub handler {
     # debugorama
     $request->debug(10);
     $redirect->debug(10);
+    $noimages->debug(10);
     $content->debug(10);
     $response->debug(10);
   }
 
   my $pipeline = Pipeline->new();
-  $pipeline->add_segment($request, $redirect, $content);
+  $pipeline->add_segment($request, $redirect, $noimages, $content);
   $pipeline->add_cleanup($response);
 
   my $store = Pipeline::Store::Simple->new();
   $pipeline->store($store->set($r));
 
-  $pipeline->dispatch();
-  return OK;
+  my $out = $pipeline->dispatch();
+  if ($out->code == ofDECLINE) {
+    return DECLINED;
+  } else {
+    return OK;
+  }
 }
 
 1;
@@ -66,7 +75,8 @@ static content.
 The actual handler is quite short. The important part is to set up a
 pipeline which has a OpenFrame::Segment::Apache::Request segment at
 the beginning and a OpenFrame::Segment::Apache::Response as a cleanup
-segment.
+segment. Also, remember to check for an ofDECLINE and return DECLINED
+in that case, or OK otherwise.
 
 =head1 AUTHOR
 
